package com.ruoyi.frequency.refereeuser.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.refereeuser.entity.RefereeUser;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.PageBasic;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 用户邀请Service接口
 * 
 * @author liwenlong
 * @date 2023-07-20
 */
public interface RefereeUserService extends IService<RefereeUser>
{
    /**
     * 查询用户邀请
     * 
     * @param id 用户邀请主键
     * @return 用户邀请
     */
    RefereeUser selectRefereeUserById(Long id);

    /**
     * 查询用户邀请列表
     * 
     * @param refereeUser 用户邀请
     * @return 用户邀请集合
     */
    List<RefereeUser> selectRefereeUserList(RefereeUser refereeUser);

    /**
     * 新增用户邀请
     * 
     * @param refereeUser 用户邀请
     * @return 结果
     */
    int insertRefereeUser(RefereeUser refereeUser);

    /**
     * 修改用户邀请
     * 
     * @param refereeUser 用户邀请
     * @return 结果
     */
    int updateRefereeUser(RefereeUser refereeUser);

    /**
     * 批量删除用户邀请
     * 
     * @param ids 需要删除的用户邀请主键集合
     * @return 结果
     */
    int deleteRefereeUserByIds(Long[] ids);

    /**
     * 删除用户邀请信息
     * 
     * @param id 用户邀请主键
     * @return 结果
     */
    int deleteRefereeUserById(Long id);


    /**
     * 邀请用户列表
     * @param req
     * @param userVo
     * @return
     */
    ResponseData refereeUserPage(PageBasic req, UserVo userVo);
}
